summaryrefslogtreecommitdiffstats
path: root/crawl-ref
diff options
context:
space:
mode:
authorDavid Lawrence Ramsey <dolorous@users.sourceforge.net>2009-09-24 11:41:35 -0500
committerDavid Lawrence Ramsey <dolorous@users.sourceforge.net>2009-09-24 11:41:35 -0500
commit1de3f0a488030ac3c1508b840ee55756fa13b84f (patch)
treec3270c0cb855da0273c54882a76e1a90749e3d7f /crawl-ref
parentc1ab37674e9eeb63f703e8c8ef44c0ed50be9720 (diff)
downloadcrawl-ref-1de3f0a488030ac3c1508b840ee55756fa13b84f.tar.gz
crawl-ref-1de3f0a488030ac3c1508b840ee55756fa13b84f.zip
Simplify.
Diffstat (limited to 'crawl-ref')
-rw-r--r--crawl-ref/source/mon-util.cc2
-rw-r--r--crawl-ref/source/mstuff2.cc10
2 files changed, 8 insertions, 4 deletions
diff --git a/crawl-ref/source/mon-util.cc b/crawl-ref/source/mon-util.cc
index ae70c01d18..2606cb7190 100644
--- a/crawl-ref/source/mon-util.cc
+++ b/crawl-ref/source/mon-util.cc
@@ -286,7 +286,7 @@ mon_resist_def get_mons_resists(const monsters *mon)
{
mon_resist_def resists;
if (mons_is_ghost_demon(mon->type))
- resists = (mon->ghost->resists);
+ resists = mon->ghost->resists;
else
resists = mon_resist_def();
diff --git a/crawl-ref/source/mstuff2.cc b/crawl-ref/source/mstuff2.cc
index cb88e2ea8e..7c618ff568 100644
--- a/crawl-ref/source/mstuff2.cc
+++ b/crawl-ref/source/mstuff2.cc
@@ -2672,10 +2672,14 @@ void mons_clear_trapping_net(monsters *mon)
bool mons_clonable(const monsters* mon, bool needs_adjacent)
{
- // No uniques, pandemonium lords or player ghosts. Also, figuring
- // out the name for the clone of a named monster isn't worth it.
- if (mons_is_unique(mon->type) || mon->is_named() || mon->ghost.get())
+ // No uniques or ghost demon monsters. Also, figuring out the name
+ // for the clone of a named monster isn't worth it.
+ if (mons_is_unique(mon->type)
+ || mons_is_ghost_demon(mon->type)
+ || mon->is_named())
+ {
return (false);
+ }
if (needs_adjacent)
{